#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 time-hourglass
version:              0.3.0
visibility:           public
id:                   time-hourglass-0.3.0-3seSJvdcpIC8dw1iefZkLR
key:                  time-hourglass-0.3.0-3seSJvdcpIC8dw1iefZkLR
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Mike Pilgrem <public@pilgrem.com>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/mpilgrem/time-hourglass
synopsis:             A simple and efficient time library
description:
    A simple and efficient time library.

    A key part of the library is the `Timeable` and `Time` type classes.

    Types representing time values that are instances of the classes allow easy
    conversion between values of one time type and another.

category:             Time
abi:                  5db4be1690ac56e56111f195690d4aea
exposed:              True
exposed-modules:
    Data.Hourglass Time.Compat Time.Epoch Time.System Time.Types

hidden-modules:
    Time.Calendar Time.Diff Time.Format Time.LocalTime Time.Time
    Time.Timezone Time.Utils Time.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/time-hourglass-0.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/time-hourglass-0.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/time-hourglass-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-time-hourglass
hs-libraries:         HStime-hourglass-0.3.0-3seSJvdcpIC8dw1iefZkLR
depends:              base-4.18.2.1 deepseq-1.4.8.1
haddock-interfaces:
    /usr/share/doc/haskell-time-hourglass/html/time-hourglass.haddock

haddock-html:         /usr/share/doc/haskell-time-hourglass/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

